@@ -5,7 +5,7 @@
 # This file is part of the R package RPACT - R Package for Adaptive Clinical Trials. #
 #                                                                                    #
 # File version: 1.0.0                                                                #
-# Date: 27 May 2019, 12:52:02                                                        #
+# Date: 11 September 2019, 16:00:40                                                  #
 # Author: Gernot Wassmer, PhD, and Friedrich Pahlke, PhD                             #
 # Licensed under "GNU Lesser General Public License" version 3                       #
 # License text can be found here: https://www.r-project.org/Licenses/LGPL-3          #
@@ -34,7 +34,6 @@ test_that("Usage of 'getDataset'", {
 	##
 	## Comparison of the results of StageResultsMeans object 'x$stageResults1' with expected results
 	##
-	expect_equal(x$stageResults1$stages, c(1, 2, 3, 4, 5))
 	expect_equal(x$stageResults1$overallTestStatistics, c(NA_real_, NA_real_, NA_real_, NA_real_, NA_real_))
 	expect_equal(x$stageResults1$overallPValues, c(NA_real_, NA_real_, NA_real_, NA_real_, NA_real_))
 	expect_equal(x$stageResults1$overallMeans1, c(1, 1.0333333, 1.02, 1.0166667), tolerance = 1e-07)
@@ -46,15 +45,10 @@ test_that("Usage of 'getDataset'", {
 	expect_equal(x$stageResults1$testStatistics, c(NA_real_, NA_real_, NA_real_, NA_real_, NA_real_))
 	expect_equal(x$stageResults1$pValues, c(NA_real_, NA_real_, NA_real_, NA_real_, NA_real_))
 	expect_equal(x$stageResults1$effectSizes, c(-0.4, -0.40380952, -1.0203509, -1.1090476), tolerance = 1e-07)
-	expect_equal(x$stageResults1$thetaH0, NA_real_)
-	expect_equal(x$stageResults1$direction, "upper")
-	expect_equal(x$stageResults1$normalApproximation, FALSE)
-	expect_equal(x$stageResults1$equalVariances, TRUE)
 
 	##
 	## Comparison of the results of StageResultsMeans object 'x$stageResults2' with expected results
 	##
-	expect_equal(x$stageResults2$stages, c(1, 2, 3, 4, 5))
 	expect_equal(x$stageResults2$overallTestStatistics, c(NA_real_, NA_real_, NA_real_, NA_real_, NA_real_))
 	expect_equal(x$stageResults2$overallPValues, c(NA_real_, NA_real_, NA_real_, NA_real_, NA_real_))
 	expect_equal(x$stageResults2$overallMeans1, c(1, 1.0333333, 1.02, 1.0166667), tolerance = 1e-07)
@@ -68,15 +62,10 @@ test_that("Usage of 'getDataset'", {
 	expect_equal(x$stageResults2$effectSizes, c(-0.4, -0.40380952, -1.0203509, -1.1090476), tolerance = 1e-07)
 	expect_equal(x$stageResults2$combInverseNormal, c(NA_real_, NA_real_, NA_real_, NA_real_, NA_real_))
 	expect_equal(x$stageResults2$weightsInverseNormal, c(0.4472136, 0.4472136, 0.4472136, 0.4472136, 0.4472136), tolerance = 1e-07)
-	expect_equal(x$stageResults2$thetaH0, NA_real_)
-	expect_equal(x$stageResults2$direction, "upper")
-	expect_equal(x$stageResults2$normalApproximation, FALSE)
-	expect_equal(x$stageResults2$equalVariances, TRUE)
 
 	##
 	## Comparison of the results of StageResultsMeans object 'x$stageResults3' with expected results
 	##
-	expect_equal(x$stageResults3$stages, c(1, 2, 3, 4, 5))
 	expect_equal(x$stageResults3$overallTestStatistics, c(NA_real_, NA_real_, NA_real_, NA_real_, NA_real_))
 	expect_equal(x$stageResults3$overallPValues, c(NA_real_, NA_real_, NA_real_, NA_real_, NA_real_))
 	expect_equal(x$stageResults3$overallMeans1, c(1, 1.0333333, 1.02, 1.0166667), tolerance = 1e-07)
@@ -90,10 +79,6 @@ test_that("Usage of 'getDataset'", {
 	expect_equal(x$stageResults3$effectSizes, c(-0.4, -0.40380952, -1.0203509, -1.1090476), tolerance = 1e-07)
 	expect_equal(x$stageResults3$combFisher, c(NA_real_, NA_real_, NA_real_, NA_real_, NA_real_))
 	expect_equal(x$stageResults3$weightsFisher, c(1, 1, 1, 1, 1), tolerance = 1e-07)
-	expect_equal(x$stageResults3$thetaH0, NA_real_)
-	expect_equal(x$stageResults3$direction, "upper")
-	expect_equal(x$stageResults3$normalApproximation, FALSE)
-	expect_equal(x$stageResults3$equalVariances, TRUE)
 
 	datasetOfMeans2 <- getDataset(data.frame(
 		stages = 1:4,
@@ -109,7 +94,6 @@ test_that("Usage of 'getDataset'", {
 	##
 	## Comparison of the results of StageResultsMeans object 'x$stageResults1' with expected results
 	##
-	expect_equal(x$stageResults1$stages, c(1, 2, 3, 4, 5))
 	expect_equal(x$stageResults1$overallTestStatistics, c(NA_real_, NA_real_, NA_real_, NA_real_, NA_real_))
 	expect_equal(x$stageResults1$overallPValues, c(NA_real_, NA_real_, NA_real_, NA_real_, NA_real_))
 	expect_equal(x$stageResults1$overallMeans1, c(1, 1.0333333, 1.02, 1.0166667), tolerance = 1e-07)
@@ -121,15 +105,10 @@ test_that("Usage of 'getDataset'", {
 	expect_equal(x$stageResults1$testStatistics, c(NA_real_, NA_real_, NA_real_, NA_real_, NA_real_))
 	expect_equal(x$stageResults1$pValues, c(NA_real_, NA_real_, NA_real_, NA_real_, NA_real_))
 	expect_equal(x$stageResults1$effectSizes, c(-0.4, -0.40380952, -1.0203509, -1.1090476), tolerance = 1e-07)
-	expect_equal(x$stageResults1$thetaH0, NA_real_)
-	expect_equal(x$stageResults1$direction, "upper")
-	expect_equal(x$stageResults1$normalApproximation, FALSE)
-	expect_equal(x$stageResults1$equalVariances, TRUE)
 
 	##
 	## Comparison of the results of StageResultsMeans object 'x$stageResults2' with expected results
 	##
-	expect_equal(x$stageResults2$stages, c(1, 2, 3, 4, 5))
 	expect_equal(x$stageResults2$overallTestStatistics, c(NA_real_, NA_real_, NA_real_, NA_real_, NA_real_))
 	expect_equal(x$stageResults2$overallPValues, c(NA_real_, NA_real_, NA_real_, NA_real_, NA_real_))
 	expect_equal(x$stageResults2$overallMeans1, c(1, 1.0333333, 1.02, 1.0166667), tolerance = 1e-07)
@@ -143,15 +122,10 @@ test_that("Usage of 'getDataset'", {
 	expect_equal(x$stageResults2$effectSizes, c(-0.4, -0.40380952, -1.0203509, -1.1090476), tolerance = 1e-07)
 	expect_equal(x$stageResults2$combInverseNormal, c(NA_real_, NA_real_, NA_real_, NA_real_, NA_real_))
 	expect_equal(x$stageResults2$weightsInverseNormal, c(0.4472136, 0.4472136, 0.4472136, 0.4472136, 0.4472136), tolerance = 1e-07)
-	expect_equal(x$stageResults2$thetaH0, NA_real_)
-	expect_equal(x$stageResults2$direction, "upper")
-	expect_equal(x$stageResults2$normalApproximation, FALSE)
-	expect_equal(x$stageResults2$equalVariances, TRUE)
 
 	##
 	## Comparison of the results of StageResultsMeans object 'x$stageResults3' with expected results
 	##
-	expect_equal(x$stageResults3$stages, c(1, 2, 3, 4, 5))
 	expect_equal(x$stageResults3$overallTestStatistics, c(NA_real_, NA_real_, NA_real_, NA_real_, NA_real_))
 	expect_equal(x$stageResults3$overallPValues, c(NA_real_, NA_real_, NA_real_, NA_real_, NA_real_))
 	expect_equal(x$stageResults3$overallMeans1, c(1, 1.0333333, 1.02, 1.0166667), tolerance = 1e-07)
@@ -165,10 +139,6 @@ test_that("Usage of 'getDataset'", {
 	expect_equal(x$stageResults3$effectSizes, c(-0.4, -0.40380952, -1.0203509, -1.1090476), tolerance = 1e-07)
 	expect_equal(x$stageResults3$combFisher, c(NA_real_, NA_real_, NA_real_, NA_real_, NA_real_))
 	expect_equal(x$stageResults3$weightsFisher, c(1, 1, 1, 1, 1), tolerance = 1e-07)
-	expect_equal(x$stageResults3$thetaH0, NA_real_)
-	expect_equal(x$stageResults3$direction, "upper")
-	expect_equal(x$stageResults3$normalApproximation, FALSE)
-	expect_equal(x$stageResults3$equalVariances, TRUE)
 
 	datasetOfMeans3 <- getDataset(
 		overallSampleSizes1 = c(22, 33, 55, 66),
@@ -183,7 +153,6 @@ test_that("Usage of 'getDataset'", {
 	##
 	## Comparison of the results of StageResultsMeans object 'x$stageResults1' with expected results
 	##
-	expect_equal(x$stageResults1$stages, c(1, 2, 3, 4, 5))
 	expect_equal(x$stageResults1$overallTestStatistics, c(NA_real_, NA_real_, NA_real_, NA_real_, NA_real_))
 	expect_equal(x$stageResults1$overallPValues, c(NA_real_, NA_real_, NA_real_, NA_real_, NA_real_))
 	expect_equal(x$stageResults1$overallMeans1, c(1, 1.033333, 1.02, 1.016667), tolerance = 1e-07)
@@ -195,15 +164,10 @@ test_that("Usage of 'getDataset'", {
 	expect_equal(x$stageResults1$testStatistics, c(NA_real_, NA_real_, NA_real_, NA_real_, NA_real_))
 	expect_equal(x$stageResults1$pValues, c(NA_real_, NA_real_, NA_real_, NA_real_, NA_real_))
 	expect_equal(x$stageResults1$effectSizes, c(-0.4, -0.40381, -1.020351, -1.109047), tolerance = 1e-07)
-	expect_equal(x$stageResults1$thetaH0, NA_real_)
-	expect_equal(x$stageResults1$direction, "upper")
-	expect_equal(x$stageResults1$normalApproximation, FALSE)
-	expect_equal(x$stageResults1$equalVariances, TRUE)
 
 	##
 	## Comparison of the results of StageResultsMeans object 'x$stageResults2' with expected results
 	##
-	expect_equal(x$stageResults2$stages, c(1, 2, 3, 4, 5))
 	expect_equal(x$stageResults2$overallTestStatistics, c(NA_real_, NA_real_, NA_real_, NA_real_, NA_real_))
 	expect_equal(x$stageResults2$overallPValues, c(NA_real_, NA_real_, NA_real_, NA_real_, NA_real_))
 	expect_equal(x$stageResults2$overallMeans1, c(1, 1.033333, 1.02, 1.016667), tolerance = 1e-07)
@@ -217,15 +181,10 @@ test_that("Usage of 'getDataset'", {
 	expect_equal(x$stageResults2$effectSizes, c(-0.4, -0.40381, -1.020351, -1.109047), tolerance = 1e-07)
 	expect_equal(x$stageResults2$combInverseNormal, c(NA_real_, NA_real_, NA_real_, NA_real_, NA_real_))
 	expect_equal(x$stageResults2$weightsInverseNormal, c(0.4472136, 0.4472136, 0.4472136, 0.4472136, 0.4472136), tolerance = 1e-07)
-	expect_equal(x$stageResults2$thetaH0, NA_real_)
-	expect_equal(x$stageResults2$direction, "upper")
-	expect_equal(x$stageResults2$normalApproximation, FALSE)
-	expect_equal(x$stageResults2$equalVariances, TRUE)
 
 	##
 	## Comparison of the results of StageResultsMeans object 'x$stageResults3' with expected results
 	##
-	expect_equal(x$stageResults3$stages, c(1, 2, 3, 4, 5))
 	expect_equal(x$stageResults3$overallTestStatistics, c(NA_real_, NA_real_, NA_real_, NA_real_, NA_real_))
 	expect_equal(x$stageResults3$overallPValues, c(NA_real_, NA_real_, NA_real_, NA_real_, NA_real_))
 	expect_equal(x$stageResults3$overallMeans1, c(1, 1.033333, 1.02, 1.016667), tolerance = 1e-07)
@@ -239,10 +198,6 @@ test_that("Usage of 'getDataset'", {
 	expect_equal(x$stageResults3$effectSizes, c(-0.4, -0.40381, -1.020351, -1.109047), tolerance = 1e-07)
 	expect_equal(x$stageResults3$combFisher, c(NA_real_, NA_real_, NA_real_, NA_real_, NA_real_))
 	expect_equal(x$stageResults3$weightsFisher, c(1, 1, 1, 1, 1), tolerance = 1e-07)
-	expect_equal(x$stageResults3$thetaH0, NA_real_)
-	expect_equal(x$stageResults3$direction, "upper")
-	expect_equal(x$stageResults3$normalApproximation, FALSE)
-	expect_equal(x$stageResults3$equalVariances, TRUE)
 
 })
 
@@ -258,7 +213,6 @@ test_that("Creation of a dataset of means using stage wise data (one group)", {
 	##
 	## Comparison of the results of StageResultsMeans object 'x$stageResults1' with expected results
 	##
-	expect_equal(x$stageResults1$stages, c(1, 2, 3, 4, 5))
 	expect_equal(x$stageResults1$overallTestStatistics, c(NA_real_, NA_real_, NA_real_, NA_real_, NA_real_))
 	expect_equal(x$stageResults1$overallPValues, c(NA_real_, NA_real_, NA_real_, NA_real_, NA_real_))
 	expect_equal(x$stageResults1$overallMeans, c(1, 1.0333333, 1.02, 1.0166667), tolerance = 1e-07)
@@ -267,14 +221,10 @@ test_that("Creation of a dataset of means using stage wise data (one group)", {
 	expect_equal(x$stageResults1$testStatistics, c(NA_real_, NA_real_, NA_real_, NA_real_, NA_real_))
 	expect_equal(x$stageResults1$pValues, c(NA_real_, NA_real_, NA_real_, NA_real_, NA_real_))
 	expect_equal(x$stageResults1$effectSizes, c(1, 1.0333333, 1.02, 1.0166667, NA_real_), tolerance = 1e-07)
-	expect_equal(x$stageResults1$thetaH0, NA_real_)
-	expect_equal(x$stageResults1$direction, "upper")
-	expect_equal(x$stageResults1$normalApproximation, FALSE)
 
 	##
 	## Comparison of the results of StageResultsMeans object 'x$stageResults2' with expected results
 	##
-	expect_equal(x$stageResults2$stages, c(1, 2, 3, 4, 5))
 	expect_equal(x$stageResults2$overallTestStatistics, c(NA_real_, NA_real_, NA_real_, NA_real_, NA_real_))
 	expect_equal(x$stageResults2$overallPValues, c(NA_real_, NA_real_, NA_real_, NA_real_, NA_real_))
 	expect_equal(x$stageResults2$overallMeans, c(1, 1.0333333, 1.02, 1.0166667), tolerance = 1e-07)
@@ -285,14 +235,10 @@ test_that("Creation of a dataset of means using stage wise data (one group)", {
 	expect_equal(x$stageResults2$effectSizes, c(1, 1.0333333, 1.02, 1.0166667, NA_real_), tolerance = 1e-07)
 	expect_equal(x$stageResults2$combInverseNormal, c(NA_real_, NA_real_, NA_real_, NA_real_, NA_real_))
 	expect_equal(x$stageResults2$weightsInverseNormal, c(0.4472136, 0.4472136, 0.4472136, 0.4472136, 0.4472136), tolerance = 1e-07)
-	expect_equal(x$stageResults2$thetaH0, NA_real_)
-	expect_equal(x$stageResults2$direction, "upper")
-	expect_equal(x$stageResults2$normalApproximation, FALSE)
 
 	##
 	## Comparison of the results of StageResultsMeans object 'x$stageResults3' with expected results
 	##
-	expect_equal(x$stageResults3$stages, c(1, 2, 3, 4, 5))
 	expect_equal(x$stageResults3$overallTestStatistics, c(NA_real_, NA_real_, NA_real_, NA_real_, NA_real_))
 	expect_equal(x$stageResults3$overallPValues, c(NA_real_, NA_real_, NA_real_, NA_real_, NA_real_))
 	expect_equal(x$stageResults3$overallMeans, c(1, 1.0333333, 1.02, 1.0166667), tolerance = 1e-07)
@@ -303,9 +249,6 @@ test_that("Creation of a dataset of means using stage wise data (one group)", {
 	expect_equal(x$stageResults3$effectSizes, c(1, 1.0333333, 1.02, 1.0166667, NA_real_), tolerance = 1e-07)
 	expect_equal(x$stageResults3$combFisher, c(NA_real_, NA_real_, NA_real_, NA_real_, NA_real_))
 	expect_equal(x$stageResults3$weightsFisher, c(1, 1, 1, 1, 1), tolerance = 1e-07)
-	expect_equal(x$stageResults3$thetaH0, NA_real_)
-	expect_equal(x$stageResults3$direction, "upper")
-	expect_equal(x$stageResults3$normalApproximation, FALSE)
 
 })
 
@@ -321,7 +264,6 @@ test_that("Creation of a dataset of means using overall data (one group)", {
 	##
 	## Comparison of the results of StageResultsMeans object 'x$stageResults1' with expected results
 	##
-	expect_equal(x$stageResults1$stages, c(1, 2, 3, 4, 5))
 	expect_equal(x$stageResults1$overallTestStatistics, c(NA_real_, NA_real_, NA_real_, NA_real_, NA_real_))
 	expect_equal(x$stageResults1$overallPValues, c(NA_real_, NA_real_, NA_real_, NA_real_, NA_real_))
 	expect_equal(x$stageResults1$overallMeans, c(1, 1.033, 1.02, 1.017), tolerance = 1e-07)
@@ -330,14 +272,10 @@ test_that("Creation of a dataset of means using overall data (one group)", {
 	expect_equal(x$stageResults1$testStatistics, c(NA_real_, NA_real_, NA_real_, NA_real_, NA_real_))
 	expect_equal(x$stageResults1$pValues, c(NA_real_, NA_real_, NA_real_, NA_real_, NA_real_))
 	expect_equal(x$stageResults1$effectSizes, c(1, 1.033, 1.02, 1.017, NA_real_), tolerance = 1e-07)
-	expect_equal(x$stageResults1$thetaH0, NA_real_)
-	expect_equal(x$stageResults1$direction, "upper")
-	expect_equal(x$stageResults1$normalApproximation, FALSE)
 
 	##
 	## Comparison of the results of StageResultsMeans object 'x$stageResults2' with expected results
 	##
-	expect_equal(x$stageResults2$stages, c(1, 2, 3, 4, 5))
 	expect_equal(x$stageResults2$overallTestStatistics, c(NA_real_, NA_real_, NA_real_, NA_real_, NA_real_))
 	expect_equal(x$stageResults2$overallPValues, c(NA_real_, NA_real_, NA_real_, NA_real_, NA_real_))
 	expect_equal(x$stageResults2$overallMeans, c(1, 1.033, 1.02, 1.017), tolerance = 1e-07)
@@ -348,14 +286,10 @@ test_that("Creation of a dataset of means using overall data (one group)", {
 	expect_equal(x$stageResults2$effectSizes, c(1, 1.033, 1.02, 1.017, NA_real_), tolerance = 1e-07)
 	expect_equal(x$stageResults2$combInverseNormal, c(NA_real_, NA_real_, NA_real_, NA_real_, NA_real_))
 	expect_equal(x$stageResults2$weightsInverseNormal, c(0.4472136, 0.4472136, 0.4472136, 0.4472136, 0.4472136), tolerance = 1e-07)
-	expect_equal(x$stageResults2$thetaH0, NA_real_)
-	expect_equal(x$stageResults2$direction, "upper")
-	expect_equal(x$stageResults2$normalApproximation, FALSE)
 
 	##
 	## Comparison of the results of StageResultsMeans object 'x$stageResults3' with expected results
 	##
-	expect_equal(x$stageResults3$stages, c(1, 2, 3, 4, 5))
 	expect_equal(x$stageResults3$overallTestStatistics, c(NA_real_, NA_real_, NA_real_, NA_real_, NA_real_))
 	expect_equal(x$stageResults3$overallPValues, c(NA_real_, NA_real_, NA_real_, NA_real_, NA_real_))
 	expect_equal(x$stageResults3$overallMeans, c(1, 1.033, 1.02, 1.017), tolerance = 1e-07)
@@ -366,9 +300,6 @@ test_that("Creation of a dataset of means using overall data (one group)", {
 	expect_equal(x$stageResults3$effectSizes, c(1, 1.033, 1.02, 1.017, NA_real_), tolerance = 1e-07)
 	expect_equal(x$stageResults3$combFisher, c(NA_real_, NA_real_, NA_real_, NA_real_, NA_real_))
 	expect_equal(x$stageResults3$weightsFisher, c(1, 1, 1, 1, 1), tolerance = 1e-07)
-	expect_equal(x$stageResults3$thetaH0, NA_real_)
-	expect_equal(x$stageResults3$direction, "upper")
-	expect_equal(x$stageResults3$normalApproximation, FALSE)
 
 })
 
@@ -383,7 +314,6 @@ test_that("Creation of a dataset of rates using stage wise data (one group)", {
 	##
 	## Comparison of the results of StageResultsRates object 'x$stageResults1' with expected results
 	##
-	expect_equal(x$stageResults1$stages, c(1, 2, 3, 4, 5))
 	expect_equal(x$stageResults1$overallTestStatistics, c(-13.929113, -20.89367, -24.622317, -28.727412, NA_real_), tolerance = 1e-07)
 	expect_equal(x$stageResults1$overallPValues, c(1, 1, 1, 1, NA_real_))
 	expect_equal(x$stageResults1$overallEvents, c(4, 9, 14, 20))
@@ -391,14 +321,10 @@ test_that("Creation of a dataset of rates using stage wise data (one group)", {
 	expect_equal(x$stageResults1$testStatistics, c(-13.929113, -15.573222, -13.098993, -14.818182, NA_real_), tolerance = 1e-07)
 	expect_equal(x$stageResults1$pValues, c(1, 1, 1, 1, NA_real_))
 	expect_equal(x$stageResults1$effectSizes, c(0.5, 0.5, 0.51851852, 0.52631579, NA_real_), tolerance = 1e-07)
-	expect_equal(x$stageResults1$thetaH0, 0.99, tolerance = 1e-07)
-	expect_equal(x$stageResults1$direction, "upper")
-	expect_equal(x$stageResults1$normalApproximation, TRUE)
 
 	##
 	## Comparison of the results of StageResultsRates object 'x$stageResults2' with expected results
 	##
-	expect_equal(x$stageResults2$stages, c(1, 2, 3, 4, 5))
 	expect_equal(x$stageResults2$overallTestStatistics, c(-13.929113, -20.89367, -24.622317, -28.727412, NA_real_), tolerance = 1e-07)
 	expect_equal(x$stageResults2$overallPValues, c(1, 1, 1, 1, NA_real_))
 	expect_equal(x$stageResults2$overallEvents, c(4, 9, 14, 20))
@@ -408,14 +334,10 @@ test_that("Creation of a dataset of rates using stage wise data (one group)", {
 	expect_equal(x$stageResults2$effectSizes, c(0.5, 0.5, 0.51851852, 0.52631579, NA_real_), tolerance = 1e-07)
 	expect_equal(x$stageResults2$combInverseNormal, c(-Inf, -Inf, -Inf, -Inf, NA_real_))
 	expect_equal(x$stageResults2$weightsInverseNormal, c(0.4472136, 0.4472136, 0.4472136, 0.4472136, 0.4472136), tolerance = 1e-07)
-	expect_equal(x$stageResults2$thetaH0, 0.99, tolerance = 1e-07)
-	expect_equal(x$stageResults2$direction, "upper")
-	expect_equal(x$stageResults2$normalApproximation, TRUE)
 
 	##
 	## Comparison of the results of StageResultsRates object 'x$stageResults3' with expected results
 	##
-	expect_equal(x$stageResults3$stages, c(1, 2, 3, 4, 5))
 	expect_equal(x$stageResults3$overallTestStatistics, c(-13.929113, -20.89367, -24.622317, -28.727412, NA_real_), tolerance = 1e-07)
 	expect_equal(x$stageResults3$overallPValues, c(1, 1, 1, 1, NA_real_))
 	expect_equal(x$stageResults3$overallEvents, c(4, 9, 14, 20))
@@ -425,9 +347,6 @@ test_that("Creation of a dataset of rates using stage wise data (one group)", {
 	expect_equal(x$stageResults3$effectSizes, c(0.5, 0.5, 0.51851852, 0.52631579, NA_real_), tolerance = 1e-07)
 	expect_equal(x$stageResults3$combFisher, c(1, 1, 1, 1, NA_real_))
 	expect_equal(x$stageResults3$weightsFisher, c(1, 1, 1, 1, 1), tolerance = 1e-07)
-	expect_equal(x$stageResults3$thetaH0, 0.99, tolerance = 1e-07)
-	expect_equal(x$stageResults3$direction, "upper")
-	expect_equal(x$stageResults3$normalApproximation, TRUE)
 
 })
 
@@ -444,7 +363,6 @@ test_that("Creation of a dataset of rates using stage wise data (two groups)", {
 	##
 	## Comparison of the results of StageResultsRates object 'x$stageResults1' with expected results
 	##
-	expect_equal(x$stageResults1$stages, c(1, 2, 3, 4, 5))
 	expect_equal(x$stageResults1$overallTestStatistics, c(-13.397899, -26.707477, -31.300879, -37.503444, NA_real_), tolerance = 1e-07)
 	expect_equal(x$stageResults1$overallPValues, c(1, 1, 1, 1, NA_real_))
 	expect_equal(x$stageResults1$overallEvents1, c(10, 20, 32, 44))
@@ -454,14 +372,10 @@ test_that("Creation of a dataset of rates using stage wise data (two groups)", {
 	expect_equal(x$stageResults1$testStatistics, c(-13.397899, -23.909016, -16.449119, -20.614826, NA_real_), tolerance = 1e-07)
 	expect_equal(x$stageResults1$pValues, c(1, 1, 1, 1, NA_real_))
 	expect_equal(x$stageResults1$effectSizes, c(0.53409091, 0.38888889, 0.40740741, 0.39795918, NA_real_), tolerance = 1e-07)
-	expect_equal(x$stageResults1$thetaH0, 0.99, tolerance = 1e-07)
-	expect_equal(x$stageResults1$direction, "upper")
-	expect_equal(x$stageResults1$normalApproximation, TRUE)
 
 	##
 	## Comparison of the results of StageResultsRates object 'x$stageResults2' with expected results
 	##
-	expect_equal(x$stageResults2$stages, c(1, 2, 3, 4, 5))
 	expect_equal(x$stageResults2$overallTestStatistics, c(-13.397899, -26.707477, -31.300879, -37.503444, NA_real_), tolerance = 1e-07)
 	expect_equal(x$stageResults2$overallPValues, c(1, 1, 1, 1, NA_real_))
 	expect_equal(x$stageResults2$overallEvents1, c(10, 20, 32, 44))
@@ -473,14 +387,10 @@ test_that("Creation of a dataset of rates using stage wise data (two groups)", {
 	expect_equal(x$stageResults2$effectSizes, c(0.53409091, 0.38888889, 0.40740741, 0.39795918, NA_real_), tolerance = 1e-07)
 	expect_equal(x$stageResults2$combInverseNormal, c(-Inf, -Inf, -Inf, -Inf, NA_real_))
 	expect_equal(x$stageResults2$weightsInverseNormal, c(0.4472136, 0.4472136, 0.4472136, 0.4472136, 0.4472136), tolerance = 1e-07)
-	expect_equal(x$stageResults2$thetaH0, 0.99, tolerance = 1e-07)
-	expect_equal(x$stageResults2$direction, "upper")
-	expect_equal(x$stageResults2$normalApproximation, TRUE)
 
 	##
 	## Comparison of the results of StageResultsRates object 'x$stageResults3' with expected results
 	##
-	expect_equal(x$stageResults3$stages, c(1, 2, 3, 4, 5))
 	expect_equal(x$stageResults3$overallTestStatistics, c(-13.397899, -26.707477, -31.300879, -37.503444, NA_real_), tolerance = 1e-07)
 	expect_equal(x$stageResults3$overallPValues, c(1, 1, 1, 1, NA_real_))
 	expect_equal(x$stageResults3$overallEvents1, c(10, 20, 32, 44))
@@ -492,26 +402,45 @@ test_that("Creation of a dataset of rates using stage wise data (two groups)", {
 	expect_equal(x$stageResults3$effectSizes, c(0.53409091, 0.38888889, 0.40740741, 0.39795918, NA_real_), tolerance = 1e-07)
 	expect_equal(x$stageResults3$combFisher, c(1, 1, 1, 1, NA_real_))
 	expect_equal(x$stageResults3$weightsFisher, c(1, 1, 1, 1, 1), tolerance = 1e-07)
-	expect_equal(x$stageResults3$thetaH0, 0.99, tolerance = 1e-07)
-	expect_equal(x$stageResults3$direction, "upper")
-	expect_equal(x$stageResults3$normalApproximation, TRUE)
+
+})
+
+test_that("Creation of a dataset of rates using stage wise data (three groups)", {
+
+	datasetOfRates3 <- getDataset(
+		n1 = c(11, 13, 12, 13),
+		n2 = c(8, 10, 9, 11),
+		n3 = c(7, 10, 8, 9),
+		events1 = c(10, 10, 12, 12),
+		events2 = c(3, 5, 5, 6),
+		events3 = c(2, 4, 3, 5)
+	)
+
+	##
+	## Comparison of the results of DatasetRates object 'datasetOfRates3' with expected results
+	##
+	expect_equal(datasetOfRates3$stages, c(1, 1, 1, 2, 2, 2, 3, 3, 3, 4, 4, 4))
+	expect_equal(datasetOfRates3$groups, c(1, 2, 3, 1, 2, 3, 1, 2, 3, 1, 2, 3))
+	expect_equal(datasetOfRates3$sampleSizes, c(11, 8, 7, 13, 10, 10, 12, 9, 8, 13, 11, 9))
+	expect_equal(datasetOfRates3$events, c(10, 3, 2, 10, 5, 4, 12, 5, 3, 12, 6, 5))
+	expect_equal(datasetOfRates3$overallSampleSizes, c(11, 8, 7, 24, 18, 17, 36, 27, 25, 49, 38, 34))
+	expect_equal(datasetOfRates3$overallEvents, c(10, 3, 2, 20, 8, 6, 32, 13, 9, 44, 19, 14))
 
 })
 
 test_that("Creation of a dataset of rates using overall data (two groups)", {
 
-	datasetOfRates3 <- getDataset(
+	datasetOfRates4 <- getDataset(
 		overallSampleSizes1 = c(11, 24, 36, 49),
 		overallSampleSizes2 = c(8, 18, 27, 38),
 		overallEvents1 = c(10, 20, 32, 44),
 		overallEvents2 = c(3, 8, 13, 19)
 	)
-	x <- getMultipleStageResultsForDataset(datasetOfRates3, thetaH0 = 0.99)
+	x <- getMultipleStageResultsForDataset(datasetOfRates4, thetaH0 = 0.99)
 
 	##
 	## Comparison of the results of StageResultsRates object 'x$stageResults1' with expected results
 	##
-	expect_equal(x$stageResults1$stages, c(1, 2, 3, 4, 5))
 	expect_equal(x$stageResults1$overallTestStatistics, c(-13.397899, -26.707477, -31.300879, -37.503444, NA_real_), tolerance = 1e-07)
 	expect_equal(x$stageResults1$overallPValues, c(1, 1, 1, 1, NA_real_))
 	expect_equal(x$stageResults1$overallEvents1, c(10, 20, 32, 44))
@@ -521,14 +450,10 @@ test_that("Creation of a dataset of rates using overall data (two groups)", {
 	expect_equal(x$stageResults1$testStatistics, c(-13.397899, -23.909016, -16.449119, -20.614826, NA_real_), tolerance = 1e-07)
 	expect_equal(x$stageResults1$pValues, c(1, 1, 1, 1, NA_real_))
 	expect_equal(x$stageResults1$effectSizes, c(0.53409091, 0.38888889, 0.40740741, 0.39795918, NA_real_), tolerance = 1e-07)
-	expect_equal(x$stageResults1$thetaH0, 0.99, tolerance = 1e-07)
-	expect_equal(x$stageResults1$direction, "upper")
-	expect_equal(x$stageResults1$normalApproximation, TRUE)
 
 	##
 	## Comparison of the results of StageResultsRates object 'x$stageResults2' with expected results
 	##
-	expect_equal(x$stageResults2$stages, c(1, 2, 3, 4, 5))
 	expect_equal(x$stageResults2$overallTestStatistics, c(-13.397899, -26.707477, -31.300879, -37.503444, NA_real_), tolerance = 1e-07)
 	expect_equal(x$stageResults2$overallPValues, c(1, 1, 1, 1, NA_real_))
 	expect_equal(x$stageResults2$overallEvents1, c(10, 20, 32, 44))
@@ -540,14 +465,10 @@ test_that("Creation of a dataset of rates using overall data (two groups)", {
 	expect_equal(x$stageResults2$effectSizes, c(0.53409091, 0.38888889, 0.40740741, 0.39795918, NA_real_), tolerance = 1e-07)
 	expect_equal(x$stageResults2$combInverseNormal, c(-Inf, -Inf, -Inf, -Inf, NA_real_))
 	expect_equal(x$stageResults2$weightsInverseNormal, c(0.4472136, 0.4472136, 0.4472136, 0.4472136, 0.4472136), tolerance = 1e-07)
-	expect_equal(x$stageResults2$thetaH0, 0.99, tolerance = 1e-07)
-	expect_equal(x$stageResults2$direction, "upper")
-	expect_equal(x$stageResults2$normalApproximation, TRUE)
 
 	##
 	## Comparison of the results of StageResultsRates object 'x$stageResults3' with expected results
 	##
-	expect_equal(x$stageResults3$stages, c(1, 2, 3, 4, 5))
 	expect_equal(x$stageResults3$overallTestStatistics, c(-13.397899, -26.707477, -31.300879, -37.503444, NA_real_), tolerance = 1e-07)
 	expect_equal(x$stageResults3$overallPValues, c(1, 1, 1, 1, NA_real_))
 	expect_equal(x$stageResults3$overallEvents1, c(10, 20, 32, 44))
@@ -559,9 +480,29 @@ test_that("Creation of a dataset of rates using overall data (two groups)", {
 	expect_equal(x$stageResults3$effectSizes, c(0.53409091, 0.38888889, 0.40740741, 0.39795918, NA_real_), tolerance = 1e-07)
 	expect_equal(x$stageResults3$combFisher, c(1, 1, 1, 1, NA_real_))
 	expect_equal(x$stageResults3$weightsFisher, c(1, 1, 1, 1, 1), tolerance = 1e-07)
-	expect_equal(x$stageResults3$thetaH0, 0.99, tolerance = 1e-07)
-	expect_equal(x$stageResults3$direction, "upper")
-	expect_equal(x$stageResults3$normalApproximation, TRUE)
+
+})
+
+test_that("Creation of a dataset of rates using overall data (three groups)", {
+
+	datasetOfRates5 <- getDataset(
+		overallSampleSizes1 = c(11, 24, 36, 49),
+		overallSampleSizes2 = c(8, 18, 27, 38),
+		overallSampleSizes3 = c(8, 18, 27, 38),
+		overallEvents1 = c(10, 20, 32, 44),
+		overallEvents2 = c(3, 8, 13, 19),
+		overallEvents3 = c(3, 7, 12, 20)
+	)
+
+	##
+	## Comparison of the results of DatasetRates object 'datasetOfRates5' with expected results
+	##
+	expect_equal(datasetOfRates5$stages, c(1, 1, 1, 2, 2, 2, 3, 3, 3, 4, 4, 4))
+	expect_equal(datasetOfRates5$groups, c(1, 2, 3, 1, 2, 3, 1, 2, 3, 1, 2, 3))
+	expect_equal(datasetOfRates5$sampleSizes, c(11, 8, 8, 13, 10, 10, 12, 9, 9, 13, 11, 11))
+	expect_equal(datasetOfRates5$events, c(10, 3, 3, 10, 5, 4, 12, 5, 5, 12, 6, 8))
+	expect_equal(datasetOfRates5$overallSampleSizes, c(11, 8, 8, 24, 18, 18, 36, 27, 27, 49, 38, 38))
+	expect_equal(datasetOfRates5$overallEvents, c(10, 3, 3, 20, 8, 7, 32, 13, 12, 44, 19, 20))
 
 })
 
@@ -577,7 +518,6 @@ test_that("Creation of a dataset of survival data using stage wise data", {
 	##
 	## Comparison of the results of StageResultsSurvival object 'x$stageResults1' with expected results
 	##
-	expect_equal(x$stageResults1$stages, c(1, 2, 3, 4, 5))
 	expect_equal(x$stageResults1$overallLogRanks, c(NA_real_, NA_real_, NA_real_, NA_real_, NA_real_))
 	expect_equal(x$stageResults1$overallPValues, c(NA_real_, NA_real_, NA_real_, NA_real_, NA_real_))
 	expect_equal(x$stageResults1$overallEvents, c(8, 15, 19, 31, NA_real_))
@@ -588,13 +528,10 @@ test_that("Creation of a dataset of survival data using stage wise data", {
 	expect_equal(x$stageResults1$pValues, c(NA_real_, NA_real_, NA_real_, NA_real_, NA_real_))
 	expect_equal(x$stageResults1$overallPValues, c(NA_real_, NA_real_, NA_real_, NA_real_, NA_real_))
 	expect_equal(x$stageResults1$effectSizes, c(2.9294137, 2.7795807, 2.4917213, 2.2339445, NA_real_), tolerance = 1e-07)
-	expect_equal(x$stageResults1$thetaH0, NA_real_)
-	expect_equal(x$stageResults1$direction, "upper")
 
 	##
 	## Comparison of the results of StageResultsSurvival object 'x$stageResults2' with expected results
 	##
-	expect_equal(x$stageResults2$stages, c(1, 2, 3, 4, 5))
 	expect_equal(x$stageResults2$overallLogRanks, c(NA_real_, NA_real_, NA_real_, NA_real_, NA_real_))
 	expect_equal(x$stageResults2$overallPValues, c(NA_real_, NA_real_, NA_real_, NA_real_, NA_real_))
 	expect_equal(x$stageResults2$overallEvents, c(8, 15, 19, 31, NA_real_))
@@ -607,13 +544,10 @@ test_that("Creation of a dataset of survival data using stage wise data", {
 	expect_equal(x$stageResults2$effectSizes, c(2.9294137, 2.7795807, 2.4917213, 2.2339445, NA_real_), tolerance = 1e-07)
 	expect_equal(x$stageResults2$combInverseNormal, c(NA_real_, NA_real_, NA_real_, NA_real_, NA_real_))
 	expect_equal(x$stageResults2$weightsInverseNormal, c(0.4472136, 0.4472136, 0.4472136, 0.4472136, 0.4472136), tolerance = 1e-07)
-	expect_equal(x$stageResults2$thetaH0, NA_real_)
-	expect_equal(x$stageResults2$direction, "upper")
 
 	##
 	## Comparison of the results of StageResultsSurvival object 'x$stageResults3' with expected results
 	##
-	expect_equal(x$stageResults3$stages, c(1, 2, 3, 4, 5))
 	expect_equal(x$stageResults3$overallLogRanks, c(NA_real_, NA_real_, NA_real_, NA_real_, NA_real_))
 	expect_equal(x$stageResults3$overallPValues, c(NA_real_, NA_real_, NA_real_, NA_real_, NA_real_))
 	expect_equal(x$stageResults3$overallEvents, c(8, 15, 19, 31, NA_real_))
@@ -626,8 +560,6 @@ test_that("Creation of a dataset of survival data using stage wise data", {
 	expect_equal(x$stageResults3$effectSizes, c(2.9294137, 2.7795807, 2.4917213, 2.2339445, NA_real_), tolerance = 1e-07)
 	expect_equal(x$stageResults3$combFisher, c(NA_real_, NA_real_, NA_real_, NA_real_, NA_real_))
 	expect_equal(x$stageResults3$weightsFisher, c(1, 1, 1, 1, 1), tolerance = 1e-07)
-	expect_equal(x$stageResults3$thetaH0, NA_real_)
-	expect_equal(x$stageResults3$direction, "upper")
 
 })
 
@@ -643,7 +575,6 @@ test_that("Creation of a dataset of survival data using overall data", {
 	##
 	## Comparison of the results of StageResultsSurvival object 'x$stageResults1' with expected results
 	##
-	expect_equal(x$stageResults1$stages, c(1, 2, 3, 4, 5))
 	expect_equal(x$stageResults1$overallLogRanks, c(NA_real_, NA_real_, NA_real_, NA_real_, NA_real_))
 	expect_equal(x$stageResults1$overallPValues, c(NA_real_, NA_real_, NA_real_, NA_real_, NA_real_))
 	expect_equal(x$stageResults1$overallEvents, c(8, 15, 19, 31, NA_real_))
@@ -654,13 +585,10 @@ test_that("Creation of a dataset of survival data using overall data", {
 	expect_equal(x$stageResults1$pValues, c(NA_real_, NA_real_, NA_real_, NA_real_, NA_real_))
 	expect_equal(x$stageResults1$overallPValues, c(NA_real_, NA_real_, NA_real_, NA_real_, NA_real_))
 	expect_equal(x$stageResults1$effectSizes, c(2.9294137, 2.7800464, 2.4919726, 2.2342616, NA_real_), tolerance = 1e-07)
-	expect_equal(x$stageResults1$thetaH0, NA_real_)
-	expect_equal(x$stageResults1$direction, "upper")
 
 	##
 	## Comparison of the results of StageResultsSurvival object 'x$stageResults2' with expected results
 	##
-	expect_equal(x$stageResults2$stages, c(1, 2, 3, 4, 5))
 	expect_equal(x$stageResults2$overallLogRanks, c(NA_real_, NA_real_, NA_real_, NA_real_, NA_real_))
 	expect_equal(x$stageResults2$overallPValues, c(NA_real_, NA_real_, NA_real_, NA_real_, NA_real_))
 	expect_equal(x$stageResults2$overallEvents, c(8, 15, 19, 31, NA_real_))
@@ -673,13 +601,10 @@ test_that("Creation of a dataset of survival data using overall data", {
 	expect_equal(x$stageResults2$effectSizes, c(2.9294137, 2.7800464, 2.4919726, 2.2342616, NA_real_), tolerance = 1e-07)
 	expect_equal(x$stageResults2$combInverseNormal, c(NA_real_, NA_real_, NA_real_, NA_real_, NA_real_))
 	expect_equal(x$stageResults2$weightsInverseNormal, c(0.4472136, 0.4472136, 0.4472136, 0.4472136, 0.4472136), tolerance = 1e-07)
-	expect_equal(x$stageResults2$thetaH0, NA_real_)
-	expect_equal(x$stageResults2$direction, "upper")
 
 	##
 	## Comparison of the results of StageResultsSurvival object 'x$stageResults3' with expected results
 	##
-	expect_equal(x$stageResults3$stages, c(1, 2, 3, 4, 5))
 	expect_equal(x$stageResults3$overallLogRanks, c(NA_real_, NA_real_, NA_real_, NA_real_, NA_real_))
 	expect_equal(x$stageResults3$overallPValues, c(NA_real_, NA_real_, NA_real_, NA_real_, NA_real_))
 	expect_equal(x$stageResults3$overallEvents, c(8, 15, 19, 31, NA_real_))
@@ -692,7 +617,34 @@ test_that("Creation of a dataset of survival data using overall data", {
 	expect_equal(x$stageResults3$effectSizes, c(2.9294137, 2.7800464, 2.4919726, 2.2342616, NA_real_), tolerance = 1e-07)
 	expect_equal(x$stageResults3$combFisher, c(NA_real_, NA_real_, NA_real_, NA_real_, NA_real_))
 	expect_equal(x$stageResults3$weightsFisher, c(1, 1, 1, 1, 1), tolerance = 1e-07)
-	expect_equal(x$stageResults3$thetaH0, NA_real_)
-	expect_equal(x$stageResults3$direction, "upper")
+
+})
+
+context("Testing that 'getDataset' throws exceptions as expected")
+
+
+test_that("Wrong parameter usage of 'getDataset'", {
+	expect_error(getDataset(), 
+		"Missing argument: data.frame or data vectors expected", fixed = TRUE)
+
+	expect_error(getDataset(1), 
+		"Illegal argument: all parameters must be named", fixed = TRUE)
+
+	expect_error(getDataset(n = 1), 
+		"Illegal argument: failed to identify dataset type", fixed = TRUE)
+
+	expect_error(getDataset(1, x = 2), 
+		"Illegal argument: all parameters must be named", fixed = TRUE)
+
+	expect_error(getDataset(
+			overallSampleSizes1 = c(11, 24, 36, 49),
+			overallSampleSizes2 = c(8, 18, 27, 38),
+			overallSampleSizes3 = c(8, 18, 27, 38),
+			overallEvents1 = c(10, 20, 32, 44),
+			overallEvents2 = c(3, 8, 13, 19),
+			overallEvents3 = c(3, 8, 13, 19),
+			overallEvents1 = c(3, 8, 13, 19)
+		), "Illegal argument: the parameter names must be unique", fixed = TRUE)
+
 })
 
